**Example 1: 示例1**



Input: 

```
tccli dlc DescribeResultDownload --cli-unfold-argument  \
    --DownloadId xx
```

Output: 
```
{
    "Response": {
        "Status": "xx",
        "Token": "xx",
        "SecretKey": "xx",
        "Reason": "xx",
        "SecretId": "xx",
        "RequestId": "xx",
        "Path": "xx"
    }
}
```

